@@ -1,4 +1,5 @@
 {-# LANGUAGE BangPatterns #-}
+{-# LANGUAGE CPP          #-}
 module Main(main) where
 
 import Control.Exception
@@ -48,8 +49,9 @@ main = do
   opts <- parseOptions ingredients (bench "Fake" (nf id ()))
   let iter = lookupOption opts
   -- Set up RNG
-  mwc <- create
-  mtg <- M.newMTGen . Just =<< uniform mwc
+  mwc  <- create
+  seed <- save mwc
+  mtg  <- M.newMTGen . Just =<< uniform mwc
   defaultMainWithIngredients ingredients $ bgroup "All"
     [ bgroup "mwc"
       -- One letter group names are used so they will fit on the plot.
@@ -91,6 +93,7 @@ main = do
         , bench "exponential" $ whnfIO $ loop iter (exponential 3 mwc :: IO Double)
         , bench "gamma,a<1"   $ whnfIO $ loop iter (gamma 0.5 1   mwc :: IO Double)
         , bench "gamma,a>1"   $ whnfIO $ loop iter (gamma 2   1   mwc :: IO Double)
+        , bench "beta"        $ whnfIO $ loop iter (beta  2   3   mwc :: IO Double)
         , bench "chiSquare"   $ whnfIO $ loop iter (chiSquare 4   mwc :: IO Double)
           -- NOTE: We switch between algorithms when Np=10
         , bgroup "binomial"
@@ -104,10 +107,6 @@ main = do
                      , (6000, 0.2), (6000, 0.8)
                      ]
           ]
-        , bench "beta binomial 10" $ whnfIO $ loop iter (betaBinomial 600 400 10 mwc :: IO Int)
-        , bench "beta binomial 100" $ whnfIO $ loop iter (betaBinomial 600 400 100 mwc :: IO Int)
-        , bench "beta binomial table 10" $ whnfIO $ loop iter (betaBinomialTable 600 400 10 mwc :: IO Int)
-        , bench "beta binomial table 100" $ whnfIO $ loop iter (betaBinomialTable 600 400 100 mwc :: IO Int)
         ]
         -- Test sampling performance. Table creation must be floated out!
       , bgroup "CT/gen" $ concat
@@ -148,14 +147,11 @@ main = do
         bench "Double" $ whnfIO $ loop iter (M.random mtg :: IO Double)
       , bench "Int"    $ whnfIO $ loop iter (M.random mtg :: IO Int)
       ]
+#if MIN_VERSION_random(1,3,0)
+    , bgroup "seed"
+      [ bench "SeedGen.fromSeed" $ let rseed = R.toSeed seed :: R.Seed Seed
+                                   in whnf R.fromSeed rseed
+      , bench "SeedGen.toSeed"   $ whnf R.toSeed seed
+      ]
+#endif
     ]
-
-betaBinomial :: StatefulGen g m => Double -> Double -> Int -> g -> m Int
-betaBinomial a b n g = do
-  p <- beta a b g
-  binomial n p g
-
-betaBinomialTable :: StatefulGen g m => Double -> Double -> Int -> g -> m Int
-betaBinomialTable a b n g = do
-  p <- beta a b g
-  genFromTable (tableBinomial n p) g
